@@ -20,13 +20,13 @@ def progress(percentage):
 	print(start + bar.ljust(progress_width, '_') + end)
 
 def notification(title="",text="This message has no content",appname="TheLocal",\
-								date="0s ago",emoji="X"):
+								date="0s ago", emoji="X"):
 	appname = emoji + "  " + appname
 	width = 50 # Width of notification
 	print('╔' + ('═' * width) + '╗')
 	appnamewidth = len(appname)
 	datewidth = len(date)
-	spacer = " " * (width - appnamewidth - datewidth) # Add a spacer so the date is on the 
+	spacer = " " * (width - appnamewidth - datewidth) # Add a spacer so the date is on the right side
 	print('║' + term.grey(appname	+ spacer + date) + '║')
 	print('║' + (" " * width) + '║')
 
@@ -42,8 +42,11 @@ def notification(title="",text="This message has no content",appname="TheLocal",
 progress(25)
 def calendar(month, year, replace = []):
 	text = cal.month(year, month)
-	for date in replace:
-		text = text.replace(f' {date} ', term.red(f' {date} ')) 
-	for line in text.split('\n'):
-		print(term.center(line))
+	lines = text.split('\n')
+	maxwidth = max(*map(len, lines)) # Get length of longest line
+	for line in lines:
+		line = term.center(line.ljust(maxwidth))
+		for date in replace:
+			line = line.replace(f' {date} ', term.cyan(f' {date} '))
+		print(line)
 
